github_tree: Create File Tree of a GitHub Repository
Description
Recursively identifies all files in a GitHub repository and creates a file tree using the data.tree package to create a simple, human-readable visualization of the folder hierarchy. Folders can be specified for exclusion in which case the number of elements within them is listed but not the names of those objects. This function only works on repositories (public or private) to which you have access.
if (FALSE) {
# Create a file tree for the `supportR` package GitHub repositorysupportR::github_tree(repo = "github.com/njlyon0/supportR", exclude = c("man", "docs", ".github"))
}