View source: R/spellcheck_quarto.r
| spellcheck_quarto | R Documentation |
Runs spelling::spell_check_files on all Quarto (.qmd) files in folders that would be rendered when rendering a Quarto project (i.e., folders that do not begin with an underscore).
spellcheck_quarto(path = getwd(), quiet = FALSE)
path |
(character) directory in which all Quarto files are to be identified and spell-checked. Recursively identifies Quarto files in folders within the top-level folder. Unrendered folders are ignored. Defaults to current working directory |
quiet |
(logical) whether to message the name of the current file being spell-checked as it is checked. Defaults to |
(dataframe) table containing a column for the Quarto file, its path, words flagged as typos by spell_check_files, and what line(s) of the file that typo was found. One row per typo. If found on multiple lines in a single file, concatenated with comma as separators.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.