Learn R Programming

supportR (version 1.5.0)

theme_lyon: Complete ggplot2 Theme for Non-Data Aesthetics

Description

Custom alternative to the ggtheme options built into ggplot2. Removes gray boxes and grid lines from plot background. Increases font size of tick marks and axis labels. Removes gray box from legend background and legend key. Removes legend title.

Usage

theme_lyon(title_size = 16, text_size = 13)

Value

(ggplot theme) list of ggplot2 theme elements

Arguments

title_size

(numeric) size of font in axis titles

text_size

(numeric) size of font in tick labels